@@ -92,7 +92,7 @@ def create_obj(client, method_name):
     # Combine in a type
     if not pref:
         pref = sd.getprefix(str_ns)
-    for_factory = pref + _(":") + str_type
+    for_factory = pref + ":" + str_type
 
     return client.factory.create(for_factory)
 
