@@ -610,7 +610,7 @@ def collect_table(field, val_list, client, wait_thread=None,
         val_table = list(convertArgDictToList(argDict))
     # standard syntax
     else:
-        reduced_list = list(split_param(val_list))
+        reduced_list = list(val_list)
         val_table = map(lambda x: x.split(':'), reduced_list)
 
     if type(field.tablevalue.values) in [list, tuple]:
