@@ -386,10 +386,6 @@ class ClApplication(Application):
                 return [resp]
             if hasattr(params, 'sid'):
                 curthread.lang = service.get_lang(params.sid, method_name)
-                if "get_methods" in method_name:
-                    with open('/tmp/getlang', 'a') as f:
-                        f.write(curthread.lang + "\n")
-                        # logging
             if curthread.client_cert:
                 certobj = OpenSSL.crypto.load_certificate(
                     OpenSSL.SSL.FILETYPE_PEM, curthread.client_cert)
